from familiar.familiar import dice_roll, get_modifier


def test_dice_roll():
    roll = dice_roll(2, 6, 0)
    print(roll)
    assert roll <= 12


def test_get_modifier():
    mod = get_modifier(12)
    assert mod == 1


def test_get_modifier_big_int():
    mod = get_modifier(18)
    assert mod == 4


def test_negative_get_modifier():
    mod = get_modifier(8)
    assert mod == -1


def test_negative_get_modifier_on_big_int():
    mod = get_modifier(4)
    assert mod == -3



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

install_requires = open('requirements.txt').read().split('\n')
install_requires = install_requires,


setup(
    name='familiar',
    version='0.0.9',
    description='Dungeons and Dragons helper functions',
    py_modules=['familiar'],
    package_dir={'': 'src'},
    # packages=['src'],
    classifiers=[
        "Framework :: Django",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Games/Entertainment :: Role-Playing"
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/JDSalisbury/familiar",
    author='Jeff Salisbury',
    author_email='pip.familiar@gmail.com'
)
